@@ -28,3 +28,6 @@ def ensure_date(dobj):
 
 def trim_mils(dobj):
     return dt.datetime(dobj.year, dobj.month, dobj.day, dobj.hour, dobj.minute, dobj.second)
+
+def trim_seconds(dobj):
+    return dt.datetime(dobj.year, dobj.month, dobj.day, dobj.hour, dobj.minute)
